==> plugin-module-codegen-maven-client-4.2.10-sources.jar: com/atlassian/maven/plugins/amps/codegen/prompter/licensing/LicensingUpm1CompatiblePrompter.java <==
package com.atlassian.maven.plugins.amps.codegen.prompter.licensing;

import com.atlassian.maven.plugins.amps.codegen.annotations.ModuleCreatorClass;
import com.atlassian.maven.plugins.amps.codegen.prompter.AbstractModulePrompter;
import com.atlassian.plugins.codegen.modules.PluginModuleLocation;
import com.atlassian.plugins.codegen.modules.common.licensing.LicensingProperties;
import com.atlassian.plugins.codegen.modules.common.licensing.LicensingUpm1CompatibleModuleCreator;
import com.atlassian.plugins.codegen.util.ClassnameUtil;

import org.codehaus.plexus.components.interactivity.Prompter;
import org.codehaus.plexus.components.interactivity.PrompterException;

/**
 * @since 3.7
 */
@ModuleCreatorClass(LicensingUpm1CompatibleModuleCreator.class)
public class LicensingUpm1CompatiblePrompter extends AbstractModulePrompter<LicensingProperties>
{
    public LicensingUpm1CompatiblePrompter(Prompter prompter)
    {
        super(prompter);
        showAdvancedPrompt = false;
    }

    @Override
    public LicensingProperties promptForBasicProperties(PluginModuleLocation moduleLocation) throws PrompterException
    {
        showExamplesPrompt = true;

        String className = promptJavaClassname("Enter License Servlet Classname", "LicenseServlet");
        String packageName = promptJavaPackagename("Enter Package Name", getDefaultBasePackage() + ".servlet");
        String licenseServletPath = prompt("Enter License Servlet URL Path (not including /plugins/servlet/)",
                                           getPluginKey() + "/license");
        
        LicensingProperties ret = new LicensingProperties(ClassnameUtil.fullyQualifiedName(packageName, className));
        ret.setLicenseServletPath(licenseServletPath);
        return ret;
    }
    
    @Override
    public LicensingProperties getModulePropertiesFromInput(PluginModuleLocation moduleLocation) throws PrompterException
    {
        LicensingProperties ret = super.getModulePropertiesFromInput(moduleLocation);
        if (ret.includeExamples())
        {
            String helloWorldServletPath = prompt("Enter Hello World Servlet URL Path (not including /plugins/servlet/)",
                                                  getPluginKey() + "/licensehelloworld");
            ret.setHelloWorldServletPath(helloWorldServletPath);
        }
        return ret;
    }
}

==> plugin-module-codegen-maven-client-6.3.11-sources.jar: com/atlassian/maven/plugins/amps/codegen/prompter/licensing/LicensingUpm1CompatiblePrompter.java <==
package com.atlassian.maven.plugins.amps.codegen.prompter.licensing;

import com.atlassian.maven.plugins.amps.codegen.annotations.ModuleCreatorClass;
import com.atlassian.maven.plugins.amps.codegen.prompter.AbstractModulePrompter;
import com.atlassian.plugins.codegen.modules.PluginModuleLocation;
import com.atlassian.plugins.codegen.modules.common.licensing.LicensingProperties;
import com.atlassian.plugins.codegen.modules.common.licensing.LicensingUpm1CompatibleModuleCreator;
import com.atlassian.plugins.codegen.util.ClassnameUtil;

import org.codehaus.plexus.components.interactivity.Prompter;
import org.codehaus.plexus.components.interactivity.PrompterException;

/**
 * @since 3.7
 */
@ModuleCreatorClass(LicensingUpm1CompatibleModuleCreator.class)
public class LicensingUpm1CompatiblePrompter extends AbstractModulePrompter<LicensingProperties>
{
    public LicensingUpm1CompatiblePrompter(Prompter prompter)
    {
        super(prompter);
        showAdvancedPrompt = false;
    }

    @Override
    public LicensingProperties promptForBasicProperties(PluginModuleLocation moduleLocation) throws PrompterException
    {
        showExamplesPrompt = true;

        boolean b = promptForBoolean("WARNING: This process applies to UPM versions prior to 2.0 only.\n" +
                "This will be deprecated in the next major AMPS release.\n"
                + "Proceed anyway?");
        if (!b) {
            throw new PrompterException("Not continuing further");
        }

        String className = promptJavaClassname("Enter License Servlet Classname", "LicenseServlet");
        String packageName = promptJavaPackagename("Enter Package Name", getDefaultBasePackage() + ".servlet");
        String licenseServletPath = prompt("Enter License Servlet URL Path (not including /plugins/servlet/)",
                                           getPluginKey() + "/license");
        
        LicensingProperties ret = new LicensingProperties(ClassnameUtil.fullyQualifiedName(packageName, className));
        ret.setLicenseServletPath(licenseServletPath);
        return ret;
    }
    
    @Override
    public LicensingProperties getModulePropertiesFromInput(PluginModuleLocation moduleLocation) throws PrompterException
    {
        LicensingProperties ret = super.getModulePropertiesFromInput(moduleLocation);
        if (ret.includeExamples())
        {
            String helloWorldServletPath = prompt("Enter Hello World Servlet URL Path (not including /plugins/servlet/)",
                                                  getPluginKey() + "/licensehelloworld");
            ret.setHelloWorldServletPath(helloWorldServletPath);
        }
        return ret;
    }
}
